import QtQuick 1.1
import com.nokia.meego 1.0
import "x3m.js" as B

Page
{
    id: aboutPage
    orientationLock: PageOrientation.Automatic;
    tools: backMenuTool

    property string versionStr: qsTr("Version ")+B.VERSION;

    property string helpText: qsTr("Unofficial YLEX app. Listen to the radio stream, see what is playing and quickly contact the studio. ")+
                              qsTr("Note: This is a third-party program and is not connected to YLE in any way.")+
                              "\n\nNote: Any future updates will be posted on the app homepage as the Nokia store will stop taking updates for N9 apps. "+
                              "See you on Jolla!";

    property string license: 'This program is free software: you can redistribute it and/or modify ' +
                             'it under the terms of the GNU General Public License as published by ' +
                             'the Free Software Foundation, either version 2 of the License, or ' +
                             '(at your option) any later version.<br /><br />' +

                             'This package is distributed in the hope that it will be useful, ' +
                             'but WITHOUT ANY WARRANTY; without even the implied warranty of ' +
                             'MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the ' +
                             'GNU General Public License for more details.<br /><br />' +

                             'You should have received a copy of the GNU General Public License ' +
                             'along with this program. If not, see <a href="http://www.gnu.org/licenses">http://www.gnu.org/licenses</a><br />'

    property string me: ""

    BackMenuTool { id: backMenuTool; }

    QueryDialog {
        id: licenseDialog
        titleText: qsTr("License");
        message: license;
        acceptButtonText: "OK"
    }

    Flickable {
        id: flick
        anchors.fill: parent
        contentHeight: aboutColumn.height

        Column {
            id: aboutColumn
            anchors.verticalCenter: parent.verticalCenter
            anchors.margins: B.DEFAULT_MARGIN
            anchors.left: parent.left
            anchors.right: parent.right
            spacing: B.DEFAULT_MARGIN

            Text
            {
                text: "YLEX\n"+versionStr
                horizontalAlignment: Text.AlignHCenter
                color: "#fffdff"
                font.pixelSize: 50
                anchors.horizontalCenter: parent.horizontalCenter
            }
            Text
            {
                id: help
                text: helpText
                styleColor: "#fbe369"
                anchors.topMargin: 20
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 22
                color: "#fbe369"
                anchors.horizontalCenter: parent.horizontalCenter
                wrapMode: Text.WordWrap
                width: parent.width
            }
            Text {
                id: links
                font.pixelSize: 22
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.topMargin: 20
                width: parent.width/3
                textFormat: Text.RichText
                color: "white"
                text: "<style>a { color: #f0f0ff; display: block; margin-left: auto; margin-right: auto;}</style>"+
                      "<a href='mailto:onion@tal.org'>onion@tal.org</a><br/>"+
                      "<a href='http://www.tal.org/'>www.tal.org</a>"
                horizontalAlignment: Text.AlignHCenter
                onLinkActivated: Qt.openUrlExternally(link)
            }

            Text
            {
                id: copyrightsgpl
                text: "Copyright 2012-2013\nKaj-Michael Lang";
                anchors.topMargin: 10
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: 20
                color: "white"
                horizontalAlignment: Text.AlignHCenter
                width: parent.width
                textFormat: Text.RichText
            }

            Button {
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr('License')
                onClicked: licenseDialog.open()
            }

            Button {
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr('Flattr it!')
                onClicked: {
                    Qt.openUrlExternally("https://flattr.com/submit/auto?user_id=oniongarlic&url=http://maemo.tal.org/index.php/maemo:radiox3m&title=YLEX&language=en_GB&tags=n9&category=software");
                }
            }

        }

    }
    ScrollDecorator {
        flickableItem: flick
    }
}
